//
//  tank
//
//  Import and Playlist Daemon for autoradio project
//
//
//  Copyright (C) 2017-2018 Christian Pointner <equinox@helsinki.at>
//
//  This file is part of tank.
//
//  tank is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  any later version.
//
//  tank is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with tank. If not, see <http://www.gnu.org/licenses/>.
//

package store

func (p *Playlist) BeforeSave() (err error) {
	for idx := range p.Entries {
		p.Entries[idx].LineNum = uint(idx)
		// TODO: fix URI String if p.Entries[idx].File is not nil
	}
	return
}

func (st *Store) ListPlaylists(group string) (playlists Playlists, err error) {
	err = st.db.Where("group_name = ?", group).Find(&playlists).Error
	return
}

func (st *Store) CreatePlaylist(group string, playlist Playlist) (*Playlist, error) {
	if _, err := st.CreateGroup(group); err != nil {
		return nil, err
	}
	playlist.ID = 0
	playlist.GroupName = group
	err := st.db.Create(&playlist).Error
	return &playlist, err
}

func (st *Store) GetPlaylist(group string, id uint64) (playlist *Playlist, err error) {
	playlist = &Playlist{}
	err = st.db.First(playlist, id).Error
	return
}

func (st *Store) UpdatePlaylist(group string, id uint64, playlist Playlist) (*Playlist, error) {
	// TODO: implement this
	return nil, ErrNotImplented
}

func (st *Store) DeletePlaylist(group string, id uint64) (err error) {
	tx := st.db.Begin()
	if err = tx.First(&Playlist{}, id).Error; err != nil {
		tx.Rollback()
		return
	}
	if err = tx.Delete(&Playlist{ID: id}).Error; err != nil {
		tx.Rollback()
		return
	}
	tx.Commit()
	return
}
